==> webix-jet-2.0.6.tgz: package/README.md <==
Webix Jet
============

[![npm version](https://badge.fury.io/js/webix-jet.svg)](https://badge.fury.io/js/webix-jet)

Micro-framework for Webix UIMicro-framework for [Webix UI](https://webix.com)


### Useful links

- Documentation: https://www.gitbook.com/book/webix/webix-jet/details
- Support Forum: https://forum.webix.com
- Demos
	- Starter app - https://github.com/webix-hub/jet-start
	- Functionality demos - https://github.com/webix-hub/jet-demos
	- Interface demo - https://github.com/webix-hub/webix-adminapp-demo
	
### Working with sources

```
//compile to es5
npm run dist

//run lint and test
npm run lint && npm run test
```

### License terms

The MIT License (MIT)    
Copyright (c) 2016 XBSoftware

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> webix-jet-3.0.0.tgz: package/README.md <==
Webix Jet
============

[![npm version](https://badge.fury.io/js/webix-jet.svg)](https://badge.fury.io/js/webix-jet)

Micro-framework for Webix UIMicro-framework for [Webix UI](https://webix.com)


### Useful links

- Documentation: https://webix.gitbook.io/webix-jet/
- Support Forum: https://forum.webix.com
- Demos
	- Starter app - https://github.com/webix-hub/jet-start
	- Functionality demos - https://github.com/webix-hub/jet-demos
	- Interface demo - https://github.com/webix-hub/webix-adminapp-demo
	
### Working with sources

```
//compile to es5
npm run dist

//run lint and test
npm run lint && npm run test
```

### License terms

The MIT License (MIT)    
Copyright (c) 2016 XBSoftware

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
